madr.mcmc: Calculate model averaged double robust estimate using a pseudo-MC3 algorithm
Description
This function uses a pseudo-MC3 algorithm to search the model space, then estimate a model averaged double robust estimate using the two-stage procedure for estimating model weights with tau=0.
Usage
madr.mcmc(Y, X, U, W = NULL, M = 1000, cut = 0.95)
Arguments
X
vector of the treatment (0/1)
U
matrix of covariates to be considered for inclusion/exclusion
W
matrix of covariates that will be included in all models (optional)
M
the number of MCMC iteration
cut
cumulative probability of models to be retained for improved computational efficiency (1 retains all visited models)
Value
A list. The list contains the following named components:
A list. The list contains the following named components: