OM.MA: Calculate model probabilities for the outcome models using a pseudo-MC3 algorithm
Description
This function uses a pseudo-MC3 algorithm to search the outcome model space.
Usage
OM.MA(Y, X, U, W = NULL, M = 1000, alpha = NULL, binary = F)
Arguments
X
vector of the treatment (0/1)
U
matrix of covariates to be considered for inclusion/exclusion
W
matrix of covariates that will be included in all models (optional)
M
the number of MCMC iteration
alpha
vector of inclusion indicators (which columns of U) to start MCMC algorithm (optional)
binary
indicator if the outcome is binary (optional)
Value
A list. The list contains the following named components:
A list. The list contains the following named components: