OM.MA.enumerate: Enumerates all possible outcome models (linear terms only)
Description
This function enumerates and fits all possible outcome models
Usage
OM.MA.enumerate(Y, X, U, W = NULL)
Arguments
X
vector of the treatment indicator (0/1)
U
matrix of covariates to be considered for inclusion/exclusion
W
matrix of covariates that will be included in all models (optional)
Value
A list. The listcontains the following named components:
A list. The listcontains the following named components: