Rdocumentation
powered by
Learn R Programming
madr (version 1.0.0)
PS.MA.enumerate: Enumerates all possible propensity score models (linear terms only)
Description
This function enumerates and fits all possible propensity score models
Usage
PS.MA.enumerate(X, U, W = NULL)
Arguments
X
vector of the treatment indicator (0/1)
U
matrix of covariates to be considered for inclusion/exclusion
W
matrix of covariates that will be included in all models (optional)
Value
A list. The list contains the following named components: A list. The list contains the following named components: