Rdocumentation
powered by
Learn R Programming
madr (version 1.0.0)
add.to.dictionary: Worker function that fits propensity score models
Description
This function fits propensity score models and saves necessary information
Usage
add.to.dictionary(X, U, W, alpha)
Arguments
X
vector of the treatment (0/1)
U
matrix of covariates to be considered for inclusion/exclusion
W
matrix of covariates that will be included in all models (optional)
alpha
vector of inclusion indicators (which columns of U) to included in the propensity score model
Value
A list. The list contains the following named components: A list. The list contains the following named components: