add.to.dictionary.outcome: Worker function that fits outcome models
Description
This function fits outcome models and saves necessary information
Usage
add.to.dictionary.outcome(Y, X, U, W, alpha, binary = F)
Arguments
X
vector of the treatment (0/1)
U
matrix of covariates to be considered for inclusion/exclusion
W
matrix of covariates that will be included in all models (optional)
alpha
vector of inclusion indicators (which columns of U) to included in the propensity score model
binary
indicates if the outcome is binary
Value
A list. The list contains the following named components:
A list. The list contains the following named components: