madr.enumerate: Model averaged double robust estimate with enumeration of all possible models (linear terms only)
Description
This function enumerates all possible models and estimates a model averaged double robust estimate
Usage
madr.enumerate(Y, X, U, W = NULL, tau = 1, two.stage = F)
Arguments
X
vector of the treatment indicator (0/1)
U
matrix of covariates to be considered for inclusion/exclusion
W
matrix of covariates that will be included in all models (optional)
tau
scalar value for the prior model dependence (1 is an independent prior)
two.stage
indicator if the two-stage procedure for calculating the model weights should be used
Value
A object of class madr.enumerate. The object contains the following named components:
A object of class madr.enumerate. The object contains the following named components: