Rdocumentation
powered by
Learn R Programming
madr (version 1.0.0)
summary.madr.enumerate: Provides model averaged double robust estimate for different values of tau
Description
This function estimates model averaged double robust estimate for different values of tau using a madr.enumerate object
Usage
"summary"(object, tau = NULL, two.stage = NULL, ...)
Arguments
object
madr.enumerate object
tau
scalar value for the prior model dependence (1 is an independent prior; defaults to value used in madr.enumerate)
two.stage
indicator if the two-stage procedure for calculating the model weights should be used (defaults to value used in madr.enumerate)
...
ignored
Value
A list. The list contains the following named components: A list. The list contains the following named components: